/*
 * File : dlFrameReject.h
 *
 * Description : This file contains the class declaration
 * for class dlFrameReject.
 */

#ifndef _dlFrameReject_h_
#define _dlFrameReject_h_


#include "dlStateMachine.h"

/* 
 * Class : dlFrameReject
 * 
 * Description : This class inherits from dlStateMachine and provides
 * the functionality for implementing the dlFrameReject state of
 * the data-link layer.
 * It redefines methods to handle DL_ResetReq, DL_DisconnectReq,
 * SABMs,DISCs, DMs, T1 timers, Iframes, RRs, RNRs, REJs,FRMRs,
 *  frames of incorrect or excess length and undefined frames.  
 */

class dlFrameReject : public dlStateMachine {

 public:
	dlFrameReject(dllayer *dl);
	virtual ~dlFrameReject() {}

	virtual dlStateMachine *DlResetReq(int &errorCode); 
	virtual dlStateMachine *DlDisconnectReq(int &errorCode); 

	virtual dlStateMachine *HandleSabm(int &errorCode); 
	virtual dlStateMachine *HandleDisc(int &errorCode); 
	virtual dlStateMachine *HandleDm(int &errorCode); 
	virtual dlStateMachine *HandleT1Timer(int &errorCode);
	virtual dlStateMachine *HandleUndefined(int &errorCode); 
	virtual dlStateMachine *HandleIncorrectLength(int &errorCode);
	virtual dlStateMachine *HandleIfrLengthExcess(int &errorCode);


	dlStateMachine *HandleIframe(int &errorCode); 
	dlStateMachine *HandleRr(int &errorCode); 
	dlStateMachine *HandleRnr(int &errorCode); 
	dlStateMachine *HandleRej(int &errorCode); 
	dlStateMachine *HandleFrmr(int &errorCode);

	virtual void PrintState(); 
 private:
	void HandleCmd(int &errorCode);
};


#endif
