/*
 * File : dlInSetupPending.C
 *
 * Description : This file contains the method definitions for
 * the dlInSetupPending class.
 */

#include "dllayer.h"
#include "phEvents.h"
#include "dlEvents.h"
#include "dlDisconnected.h"
#include "dlInSetupPending.h"
#include "dlInfoXfer.h"
#include "frame.h"

/*
 * Function : dlInSetupPending()
 *
 * Description : Constructor. Calls base class constructor, and
 *	sets _lastPbit.
 */

dlInSetupPending::dlInSetupPending(dllayer *dl) : dlStateMachine(dl)
{
	_lastPBit = dl->_lastFrameRecd->GetPf();
}
/*
 * Function : DlConnectRes()
 *
 * Description : This method handles the primitive DL_ConnectRes.
 *	If the dlInSetupPending state was entered from dlDisconnected (i.e.
 *	initial ) then a UA is transmitted, and state changed to 
 *	dlInfoXfer. Otherwise the primitive is ignored.
 */

dlStateMachine *
dlInSetupPending::DlConnectRes(int &errorCode) 
{
	TRACE(dlSmModule,1,("dlInSetupPending: In DlConnectRes\n"));

	// If the state was not entered because of an initial link
	// setup, ignore a DlConnectRes
	
	if ( _dl->_setupType != initial )
		return this;
	
	// Transmit a UA
	_dl->XmitFrame(errorCode,FALSE,UA,_lastPBit);
	CHANGE_TO_INFOXFER(TRUE);
}

/*
 * Function : DlDisconnectReq()
 *
 * Description : This method handles the DL_DisconnectReq primitive.
 *	It transmits a DM response, and changes state to dlDisconnected.
 */

dlStateMachine *
dlInSetupPending::DlDisconnectReq(int &errorCode)
 {
	TRACE(dlSmModule,1,("dlInSetupPending: In DlDisconnectReq\n"));

	// Transmit A DM
	_dl->XmitFrame(errorCode,FALSE,DM,_lastPBit);
	CHANGE_STATE(dlDisconnected);
}

/*
 * Function : DlResetRes()
 *
 * Description : This method handles the primitive DL_ResetRes.
 *	If the dlInSetupPending state was entered from dlInfoXfer due to
 *	a SABM that was received (i.e. externalReset) then a UA is 
 *  transmitted, and state changed to dlInfoXfer. 
 *	Otherwise the primitive is ignored.
 */

dlStateMachine *
dlInSetupPending::DlResetRes(int &errorCode)
{
	TRACE(dlSmModule,1,("dlInSetupPending: In DlResetRes\n"));

	// If reset was not because of an externalReset,
	// ignore Reset Response
	
	if ( _dl->_setupType != externalReset )
		return this;
	
	// Transmit a UA
	_dl->XmitFrame(errorCode,FALSE,UA,_lastPBit);
	CHANGE_TO_INFOXFER(TRUE);
}

/*
 * Function : HandleDisc()
 *
 * Description : This function handles a DISC command recevied.
 *	It transmits a UA response, invokes a DL_DisconnectInd and
 *	changes state to dlDisconnected.
 */

dlStateMachine *
dlInSetupPending::HandleDisc(int &errorCode)
{
	TRACE(dlSmModule,1,("dlInSetupPending: In HandleDisc\n"));

	// Send UA to peer DL
	_dl->XmitFrame(errorCode,FALSE,UA,_dl->_lastFrameRecd->GetPf());

	// Notify NW layer of Disconnection
	_dl->_nPlus1->Command(DL_DisconnectInd,errorCode,peerDisconnect);
	CHANGE_STATE(dlDisconnected);
}
 
/*
 * Function : PrintState
 *
 * Description : Prints state.
 */

void 
dlInSetupPending::PrintState() 
{
	TRACE(dlSmModule,1,("State dlInSetupPending\n"));
}

