/*
 * File : eventHandler.h
 * 
 * Description: This file contains the base class definition
 * 	for an event handler. 
 */

#ifndef _eventHandler_h_
#define _eventHandler_h_

#include <libc.h>
#include <sys/time.h>
#include "list.h"

/*
 * First - create type-safe lists of eventHandler objects
 */

class eventHandler;
DefineListMember(eventHandler);
DefineList(eventHandler);

/*
 * Class : eventHandler
 *
 * Description : This class is the base class for all types
 * of event handlers. Sub-classes inheriting from eventHandler
 * will provide special functionality for handling input,
 * timers etc. 
 */

class eventHandler : public eventHandlerMember {

 public:

	eventHandler();
	virtual ~eventHandler(); 

	virtual void EventCallback(); 


	virtual void SetEvent(fd_set *readfds,
		fd_set *writefds, fd_set *exceptfds,
		struct timeval *timeout) = 0;

	virtual void CheckEvent(fd_set *readfds,
		fd_set *writefds, fd_set *exceptfds,
		struct timeval *curtime) = 0;
};

#endif
