/*
 * File : timerT1.h
 *
 * Description : This file contains the declaration for class timerT1.
 */

#ifndef _timerT1_h_
#define _timerT1_h_


#include "types.h"
#include "timerHandler.h"

class dllayer;

/*
 * Class : timerT1
 *
 * Description : The timerT1 class inherits from timerHandler class to
 *	provide T1 timers for the data-link layer. Each timer that
 *  is created by the data-link layer is associated with an event
 *	that will occur when the timer expires. This event type is stored
 *	in the timerT1 object. When the timer expires, the scheduler will
 *	call the EventCallback method, which has been redefined here to
 *	invoke ProcessEvent on the dllayer object with the stored event
 *	type.
 *
 * Attributes:
 *	int _event : The event type that will occur when the timer expires.
 *	dllayer *_dl : A pointer to the data-link layer.
 */

class timerT1 : public timerHandler {

 public:

	timerT1(int event, dllayer *dl, int timeout = T1);
	virtual ~timerT1();
	virtual void EventCallback();

 private:
	int	_event;
	dllayer *_dl;
};

#endif
